function createAreaChart(data) {
  // Convert numerical values from string to float
  data.forEach(function (d) {
    d['Happiness Score'] = +d['Happiness Score'];
    // Add conversion for other numerical columns if necessary
  });

  // Set up the dimensions for the chart
  const width = 800;
  const height = 400;
  const margin = {
    top: 20,
    right: 20,
    bottom: 50,
    left: 50,
  }; // Increased bottom margin for Y-axis label

  // Create SVG element
  const svg = d3
    .select('#chart-container')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // Define scales
  const xScale = d3
    .scaleBand()
    .domain(data.map((d) => d.Country))
    .range([0, width])
    .padding(0.1);

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d['Happiness Score'])])
    .range([height, 0]);

  // Create and draw the area
  const area = d3
    .area()
    .x((d) => xScale(d.Country))
    .y0(yScale(0))
    .y1((d) => yScale(d['Happiness Score']));

  svg
    .append('path')
    .datum(data)
    .attr('fill', 'steelblue')
    .attr('d', area);

  // Add X-axis
  svg
    .append('g')
    .attr('transform', `translate(0,${height})`)
    .call(d3.axisBottom(xScale))
    .selectAll('text')
    .style('text-anchor', 'end')
    .attr('transform', 'rotate(-45)');

  // Add Y-axis
  svg.append('g').call(d3.axisLeft(yScale));

  // Add X-axis label
  svg
    .append('text')
    .attr(
      'transform',
      `translate(${width / 2},${height + margin.top + 30})`,
    ) // Adjusted y-coordinate
    .style('text-anchor', 'middle')
    .text('Country');

  // Add Y-axis label
  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', 0 - margin.left)
    .attr('x', 0 - height / 2)
    .attr('dy', '1em')
    .style('text-anchor', 'middle')
    .text('Happiness Score');
}
